@@ -16,12 +16,11 @@
 #![allow(dead_code)]
 #![allow(incomplete_features)]
 #![deny(unused_must_use)]
-#![feature(impl_trait_in_bindings)]
 #![feature(in_band_lifetimes)]
 #![feature(path_try_exists)]
 #![feature(const_evaluatable_checked)]
 #![feature(const_generics)]
-#![feature(min_type_alias_impl_trait)]
+#![feature(type_alias_impl_trait)]
 #![feature(once_cell)]
 #![feature(step_trait)]
 #![feature(option_get_or_insert_default)]
@@ -29,6 +28,7 @@
 #![feature(test)]
 #![feature(box_syntax)]
 #![feature(default_free_fn)]
+#![feature(bool_to_option)]
 
 #[macro_use]
 extern crate enum_dispatch;
